aboutsummaryrefslogtreecommitdiffstats
path: root/python_client
diff options
context:
space:
mode:
authorBryan Newbold <bnewbold@robocracy.org>2019-01-21 12:02:14 -0800
committerBryan Newbold <bnewbold@robocracy.org>2019-01-21 12:02:14 -0800
commit4c54f3bf32e0d0e9dbe52b22f911027a667c0e34 (patch)
tree3d62f87300a7d3ab3527842bd021fb14778d789a /python_client
parentfd2b76909c5ceae22d6634dd24a11025f6847b2d (diff)
downloadfatcat-4c54f3bf32e0d0e9dbe52b22f911027a667c0e34.tar.gz
fatcat-4c54f3bf32e0d0e9dbe52b22f911027a667c0e34.zip
codegen
Diffstat (limited to 'python_client')
-rw-r--r--python_client/fatcat_client/models/container_entity.py82
-rw-r--r--python_client/fatcat_client/models/release_contrib.py84
-rw-r--r--python_client/fatcat_client/models/release_entity.py114
3 files changed, 196 insertions, 84 deletions
diff --git a/python_client/fatcat_client/models/container_entity.py b/python_client/fatcat_client/models/container_entity.py
index 5ed7eb0a..f5a054c5 100644
--- a/python_client/fatcat_client/models/container_entity.py
+++ b/python_client/fatcat_client/models/container_entity.py
@@ -31,11 +31,10 @@ class ContainerEntity(object):
and the value is json key in definition.
"""
swagger_types = {
- 'coden': 'str',
- 'abbrev': 'str',
'wikidata_qid': 'str',
'issnl': 'str',
'publisher': 'str',
+ 'container_type': 'str',
'name': 'str',
'edit_extra': 'object',
'extra': 'object',
@@ -46,11 +45,10 @@ class ContainerEntity(object):
}
attribute_map = {
- 'coden': 'coden',
- 'abbrev': 'abbrev',
'wikidata_qid': 'wikidata_qid',
'issnl': 'issnl',
'publisher': 'publisher',
+ 'container_type': 'container_type',
'name': 'name',
'edit_extra': 'edit_extra',
'extra': 'extra',
@@ -60,14 +58,13 @@ class ContainerEntity(object):
'state': 'state'
}
- def __init__(self, coden=None, abbrev=None, wikidata_qid=None, issnl=None, publisher=None, name=None, edit_extra=None, extra=None, redirect=None, revision=None, ident=None, state=None): # noqa: E501
+ def __init__(self, wikidata_qid=None, issnl=None, publisher=None, container_type=None, name=None, edit_extra=None, extra=None, redirect=None, revision=None, ident=None, state=None): # noqa: E501
"""ContainerEntity - a model defined in Swagger""" # noqa: E501
- self._coden = None
- self._abbrev = None
self._wikidata_qid = None
self._issnl = None
self._publisher = None
+ self._container_type = None
self._name = None
self._edit_extra = None
self._extra = None
@@ -77,16 +74,14 @@ class ContainerEntity(object):
self._state = None
self.discriminator = None
- if coden is not None:
- self.coden = coden
- if abbrev is not None:
- self.abbrev = abbrev
if wikidata_qid is not None:
self.wikidata_qid = wikidata_qid
if issnl is not None:
self.issnl = issnl
if publisher is not None:
self.publisher = publisher
+ if container_type is not None:
+ self.container_type = container_type
if name is not None:
self.name = name
if edit_extra is not None:
@@ -103,48 +98,6 @@ class ContainerEntity(object):
self.state = state
@property
- def coden(self):
- """Gets the coden of this ContainerEntity. # noqa: E501
-
-
- :return: The coden of this ContainerEntity. # noqa: E501
- :rtype: str
- """
- return self._coden
-
- @coden.setter
- def coden(self, coden):
- """Sets the coden of this ContainerEntity.
-
-
- :param coden: The coden of this ContainerEntity. # noqa: E501
- :type: str
- """
-
- self._coden = coden
-
- @property
- def abbrev(self):
- """Gets the abbrev of this ContainerEntity. # noqa: E501
-
-
- :return: The abbrev of this ContainerEntity. # noqa: E501
- :rtype: str
- """
- return self._abbrev
-
- @abbrev.setter
- def abbrev(self, abbrev):
- """Sets the abbrev of this ContainerEntity.
-
-
- :param abbrev: The abbrev of this ContainerEntity. # noqa: E501
- :type: str
- """
-
- self._abbrev = abbrev
-
- @property
def wikidata_qid(self):
"""Gets the wikidata_qid of this ContainerEntity. # noqa: E501
@@ -214,6 +167,29 @@ class ContainerEntity(object):
self._publisher = publisher
@property
+ def container_type(self):
+ """Gets the container_type of this ContainerEntity. # noqa: E501
+
+ Eg, 'journal' # noqa: E501
+
+ :return: The container_type of this ContainerEntity. # noqa: E501
+ :rtype: str
+ """
+ return self._container_type
+
+ @container_type.setter
+ def container_type(self, container_type):
+ """Sets the container_type of this ContainerEntity.
+
+ Eg, 'journal' # noqa: E501
+
+ :param container_type: The container_type of this ContainerEntity. # noqa: E501
+ :type: str
+ """
+
+ self._container_type = container_type
+
+ @property
def name(self):
"""Gets the name of this ContainerEntity. # noqa: E501
diff --git a/python_client/fatcat_client/models/release_entity.py b/python_client/fatcat_client/models/release_entity.py
index 83648351..5df97e50 100644
--- a/python_client/fatcat_client/models/release_entity.py
+++ b/python_client/fatcat_client/models/release_entity.py
@@ -42,11 +42,14 @@ class ReleaseEntity(object):
'abstracts': 'list[ReleaseEntityAbstracts]',
'refs': 'list[ReleaseRef]',
'contribs': 'list[ReleaseContrib]',
+ 'license_slug': 'str',
'language': 'str',
'publisher': 'str',
'pages': 'str',
'issue': 'str',
'volume': 'str',
+ 'jstor_id': 'str',
+ 'arxiv_id': 'str',
'core_id': 'str',
'pmcid': 'str',
'pmid': 'str',
@@ -63,6 +66,7 @@ class ReleaseEntity(object):
'files': 'list[FileEntity]',
'container': 'ContainerEntity',
'work_id': 'str',
+ 'original_title': 'str',
'title': 'str',
'state': 'str',
'ident': 'str',
@@ -76,11 +80,14 @@ class ReleaseEntity(object):
'abstracts': 'abstracts',
'refs': 'refs',
'contribs': 'contribs',
+ 'license_slug': 'license_slug',
'language': 'language',
'publisher': 'publisher',
'pages': 'pages',
'issue': 'issue',
'volume': 'volume',
+ 'jstor_id': 'jstor_id',
+ 'arxiv_id': 'arxiv_id',
'core_id': 'core_id',
'pmcid': 'pmcid',
'pmid': 'pmid',
@@ -97,6 +104,7 @@ class ReleaseEntity(object):
'files': 'files',
'container': 'container',
'work_id': 'work_id',
+ 'original_title': 'original_title',
'title': 'title',
'state': 'state',
'ident': 'ident',
@@ -106,17 +114,20 @@ class ReleaseEntity(object):
'edit_extra': 'edit_extra'
}
- def __init__(self, abstracts=None, refs=None, contribs=None, language=None, publisher=None, pages=None, issue=None, volume=None, core_id=None, pmcid=None, pmid=None, isbn13=None, wikidata_qid=None, doi=None, release_year=None, release_date=None, release_status=None, release_type=None, container_id=None, webcaptures=None, filesets=None, files=None, container=None, work_id=None, title=None, state=None, ident=None, revision=None, redirect=None, extra=None, edit_extra=None): # noqa: E501
+ def __init__(self, abstracts=None, refs=None, contribs=None, license_slug=None, language=None, publisher=None, pages=None, issue=None, volume=None, jstor_id=None, arxiv_id=None, core_id=None, pmcid=None, pmid=None, isbn13=None, wikidata_qid=None, doi=None, release_year=None, release_date=None, release_status=None, release_type=None, container_id=None, webcaptures=None, filesets=None, files=None, container=None, work_id=None, original_title=None, title=None, state=None, ident=None, revision=None, redirect=None, extra=None, edit_extra=None): # noqa: E501
"""ReleaseEntity - a model defined in Swagger""" # noqa: E501
self._abstracts = None
self._refs = None
self._contribs = None
+ self._license_slug = None
self._language = None
self._publisher = None
self._pages = None
self._issue = None
self._volume = None
+ self._jstor_id = None
+ self._arxiv_id = None
self._core_id = None
self._pmcid = None
self._pmid = None
@@ -133,6 +144,7 @@ class ReleaseEntity(object):
self._files = None
self._container = None
self._work_id = None
+ self._original_title = None
self._title = None
self._state = None
self._ident = None
@@ -148,6 +160,8 @@ class ReleaseEntity(object):
self.refs = refs
if contribs is not None:
self.contribs = contribs
+ if license_slug is not None:
+ self.license_slug = license_slug
if language is not None:
self.language = language
if publisher is not None:
@@ -158,6 +172,10 @@ class ReleaseEntity(object):
self.issue = issue
if volume is not None:
self.volume = volume
+ if jstor_id is not None:
+ self.jstor_id = jstor_id
+ if arxiv_id is not None:
+ self.arxiv_id = arxiv_id
if core_id is not None:
self.core_id = core_id
if pmcid is not None:
@@ -190,6 +208,8 @@ class ReleaseEntity(object):
self.container = container
if work_id is not None:
self.work_id = work_id
+ if original_title is not None:
+ self.original_title = original_title
if title is not None:
self.title = title
if state is not None:
@@ -269,6 +289,29 @@ class ReleaseEntity(object):
self._contribs = contribs
@property
+ def license_slug(self):
+ """Gets the license_slug of this ReleaseEntity. # noqa: E501
+
+ Short version of license name. Eg, 'CC-BY' # noqa: E501
+
+ :return: The license_slug of this ReleaseEntity. # noqa: E501
+ :rtype: str
+ """
+ return self._license_slug
+
+ @license_slug.setter
+ def license_slug(self, license_slug):
+ """Sets the license_slug of this ReleaseEntity.
+
+ Short version of license name. Eg, 'CC-BY' # noqa: E501
+
+ :param license_slug: The license_slug of this ReleaseEntity. # noqa: E501
+ :type: str
+ """
+
+ self._license_slug = license_slug
+
+ @property
def language(self):
"""Gets the language of this ReleaseEntity. # noqa: E501
@@ -376,6 +419,48 @@ class ReleaseEntity(object):
self._volume = volume
@property
+ def jstor_id(self):
+ """Gets the jstor_id of this ReleaseEntity. # noqa: E501
+
+
+ :return: The jstor_id of this ReleaseEntity. # noqa: E501
+ :rtype: str
+ """
+ return self._jstor_id
+
+ @jstor_id.setter
+ def jstor_id(self, jstor_id):
+ """Sets the jstor_id of this ReleaseEntity.
+
+
+ :param jstor_id: The jstor_id of this ReleaseEntity. # noqa: E501
+ :type: str
+ """
+
+ self._jstor_id = jstor_id
+
+ @property
+ def arxiv_id(self):
+ """Gets the arxiv_id of this ReleaseEntity. # noqa: E501
+
+
+ :return: The arxiv_id of this ReleaseEntity. # noqa: E501
+ :rtype: str
+ """
+ return self._arxiv_id
+
+ @arxiv_id.setter
+ def arxiv_id(self, arxiv_id):
+ """Sets the arxiv_id of this ReleaseEntity.
+
+
+ :param arxiv_id: The arxiv_id of this ReleaseEntity. # noqa: E501
+ :type: str
+ """
+
+ self._arxiv_id = arxiv_id
+
+ @property
def core_id(self):
"""Gets the core_id of this ReleaseEntity. # noqa: E501
@@ -720,10 +805,33 @@ class ReleaseEntity(object):
self._work_id = work_id
@property
+ def original_title(self):
+ """Gets the original_title of this ReleaseEntity. # noqa: E501
+
+ Title in original language (or, the language of the full text of this release) # noqa: E501
+
+ :return: The original_title of this ReleaseEntity. # noqa: E501
+ :rtype: str
+ """
+ return self._original_title
+
+ @original_title.setter
+ def original_title(self, original_title):
+ """Sets the original_title of this ReleaseEntity.
+
+ Title in original language (or, the language of the full text of this release) # noqa: E501
+
+ :param original_title: The original_title of this ReleaseEntity. # noqa: E501
+ :type: str
+ """
+
+ self._original_title = original_title
+
+ @property
def title(self):
"""Gets the title of this ReleaseEntity. # noqa: E501
- Required for valid entities # noqa: E501
+ Required for valid entities. The title used in citations and for display; usually English # noqa: E501
:return: The title of this ReleaseEntity. # noqa: E501
:rtype: str
@@ -734,7 +842,7 @@ class ReleaseEntity(object):
def title(self, title):
"""Sets the title of this ReleaseEntity.
- Required for valid entities # noqa: E501
+ Required for valid entities. The title used in citations and for display; usually English # noqa: E501
:param title: The title of this ReleaseEntity. # noqa: E501
:type: str
diff --git a/python_client/fatcat_client/models/release_contrib.py b/python_client/fatcat_client/models/release_contrib.py
index a06b0e66..e823e43e 100644
--- a/python_client/fatcat_client/models/release_contrib.py
+++ b/python_client/fatcat_client/models/release_contrib.py
@@ -37,8 +37,9 @@ class ReleaseContrib(object):
'creator_id': 'str',
'creator': 'CreatorEntity',
'raw_name': 'str',
- 'extra': 'object',
- 'role': 'str'
+ 'role': 'str',
+ 'raw_affiliation': 'str',
+ 'extra': 'object'
}
attribute_map = {
@@ -46,19 +47,21 @@ class ReleaseContrib(object):
'creator_id': 'creator_id',
'creator': 'creator',
'raw_name': 'raw_name',
- 'extra': 'extra',
- 'role': 'role'
+ 'role': 'role',
+ 'raw_affiliation': 'raw_affiliation',
+ 'extra': 'extra'
}
- def __init__(self, index=None, creator_id=None, creator=None, raw_name=None, extra=None, role=None): # noqa: E501
+ def __init__(self, index=None, creator_id=None, creator=None, raw_name=None, role=None, raw_affiliation=None, extra=None): # noqa: E501
"""ReleaseContrib - a model defined in Swagger""" # noqa: E501
self._index = None
self._creator_id = None
self._creator = None
self._raw_name = None
- self._extra = None
self._role = None
+ self._raw_affiliation = None
+ self._extra = None
self.discriminator = None
if index is not None:
@@ -69,10 +72,12 @@ class ReleaseContrib(object):
self.creator = creator
if raw_name is not None:
self.raw_name = raw_name
- if extra is not None:
- self.extra = extra
if role is not None:
self.role = role
+ if raw_affiliation is not None:
+ self.raw_affiliation = raw_affiliation
+ if extra is not None:
+ self.extra = extra
@property
def index(self):
@@ -161,46 +166,69 @@ class ReleaseContrib(object):
self._raw_name = raw_name
@property
- def extra(self):
- """Gets the extra of this ReleaseContrib. # noqa: E501
+ def role(self):
+ """Gets the role of this ReleaseContrib. # noqa: E501
- :return: The extra of this ReleaseContrib. # noqa: E501
- :rtype: object
+ :return: The role of this ReleaseContrib. # noqa: E501
+ :rtype: str
"""
- return self._extra
+ return self._role
- @extra.setter
- def extra(self, extra):
- """Sets the extra of this ReleaseContrib.
+ @role.setter
+ def role(self, role):
+ """Sets the role of this ReleaseContrib.
- :param extra: The extra of this ReleaseContrib. # noqa: E501
- :type: object
+ :param role: The role of this ReleaseContrib. # noqa: E501
+ :type: str
"""
- self._extra = extra
+ self._role = role
@property
- def role(self):
- """Gets the role of this ReleaseContrib. # noqa: E501
+ def raw_affiliation(self):
+ """Gets the raw_affiliation of this ReleaseContrib. # noqa: E501
+ Raw affiliation string as displayed in text # noqa: E501
- :return: The role of this ReleaseContrib. # noqa: E501
+ :return: The raw_affiliation of this ReleaseContrib. # noqa: E501
:rtype: str
"""
- return self._role
+ return self._raw_affiliation
- @role.setter
- def role(self, role):
- """Sets the role of this ReleaseContrib.
+ @raw_affiliation.setter
+ def raw_affiliation(self, raw_affiliation):
+ """Sets the raw_affiliation of this ReleaseContrib.
+ Raw affiliation string as displayed in text # noqa: E501
- :param role: The role of this ReleaseContrib. # noqa: E501
+ :param raw_affiliation: The raw_affiliation of this ReleaseContrib. # noqa: E501
:type: str
"""
- self._role = role
+ self._raw_affiliation = raw_affiliation
+
+ @property
+ def extra(self):
+ """Gets the extra of this ReleaseContrib. # noqa: E501
+
+
+ :return: The extra of this ReleaseContrib. # noqa: E501
+ :rtype: object
+ """
+ return self._extra
+
+ @extra.setter
+ def extra(self, extra):
+ """Sets the extra of this ReleaseContrib.
+
+
+ :param extra: The extra of this ReleaseContrib. # noqa: E501
+ :type: object
+ """
+
+ self._extra = extra
def to_dict(self):
"""Returns the model properties as a dict"""